@@ -40,6 +40,10 @@ import sys
 import json
 import re
 
+import matplotlib.pyplot as plt
+
+plt.style.use("fivethirtyeight")
+
 from requests.models import Response
 from typing import Dict
 from urllib.parse import quote_plus
@@ -795,6 +799,13 @@ class ModelSet:
             df.columns = ["help"]
             return df
 
+    def plot_guidance(self, ticker, time_series_name):
+        if ticker not in self.ticker_list:
+            print("Please choose a ticker in this ModelSet")
+            return
+        self.models[ticker].plot_guidance(time_series_name)
+        return
+
     def pe_dataset(self, ticker, yahoo_ticker, index_ticker="^GSPC", n_periods=24):
         import canalyst_candas.candas_datareader as cdr
 
@@ -1691,6 +1702,82 @@ class Model:
             self._model_name = self.get_excel_model_name()
             self._model_frame["model_name"] = self._model_name
 
+    def plot_guidance(self, time_series_name):
+        df_guidance = self.guidance()
+        df_guidance["time_series_name"] = time_series_name
+        df_guidance["period_name"] = df_guidance["Fiscal Period"]
+        df_guidance["Actual"] = df_guidance["Output"]
+        df_guidance = df_guidance[df_guidance["Item Name"] == time_series_name][
+            [
+                "time_series_name",
+                "period_name",
+                "Low",
+                "High",
+                "Mid",
+                "Type.1",
+                "Actual",
+            ]
+        ]
+        df_guidance = (
+            df_guidance.groupby(["time_series_name", "period_name"])
+            .first()
+            .reset_index()
+        )
+
+        i_low = df_guidance["Low"].sum()
+        i_mid = df_guidance["Mid"].sum()
+        i_high = df_guidance["High"].sum()
+
+        if len({i_low, i_mid, i_high}) == 1:
+            i_three = True
+        else:
+            i_three = False
+
+        colors = {
+            "red": "#ff207c",
+            "grey": "#C3C2C3",
+            "blue": "#00838F",
+            "orange": "#ffa320",
+            "green": "#00ec8b",
+        }
+
+        plt.rc("figure", figsize=(12, 9))
+        plt.title(time_series_name)
+        plt.plot(
+            df_guidance["period_name"],
+            df_guidance["Actual"],
+            label="Actual",
+            color=colors["blue"],
+            linewidth=2,
+        )
+        plt.plot(
+            df_guidance["period_name"],
+            df_guidance["Mid"],
+            label="Mid",
+            color=colors["orange"],
+            linewidth=2,
+        )
+
+        if i_three == False:
+            plt.plot(
+                df_guidance["period_name"],
+                df_guidance["Low"],
+                label="Low",
+                color=colors["red"],
+                linewidth=2,
+            )
+            plt.plot(
+                df_guidance["period_name"],
+                df_guidance["High"],
+                label="High",
+                color=colors["green"],
+                linewidth=2,
+            )
+
+        plt.legend()
+        plt.show()
+        return
+
     def get_most_recent_model_date(self):
 
         csin = self.csin
@@ -1870,16 +1957,29 @@ class Model:
         title = self.ticker + " " + row1["time_series_description"]
         xlabel = "Fiscal Quarter"
         ylabel = row1["time_series_description"]
-        # plot data
-        fig = px.line(
-            df,
-            x="period_name",
-            y="value",
-            title=title,
-            labels={"period_name": xlabel, "value": ylabel},
+
+        colors = {
+            "red": "#ff207c",
+            "grey": "#C3C2C3",
+            "blue": "#00838F",
+            "orange": "#ffa320",
+            "green": "#00ec8b",
+        }
+
+        plt.rc("figure", figsize=(12, 9))
+        plt.title(time_series_name)
+        plt.plot(
+            df["period_name"],
+            df["value"],
+            label=ylabel,
+            color=colors["blue"],
+            linewidth=2,
         )
-        fig.add_vline(x=self.mrq()["period_name"][0])
-        fig.show()
+        plt.axvline(x=self.mrq()["period_name"][0])
+        plt.xticks(rotation=90)
+        plt.legend()
+        plt.show()
+
         return
 
     def create_model_map(
